pub struct DefaultPrivilegeGrantSpec {
pub role: Option<String>,
pub privileges: Vec<Privilege>,
pub on_type: ObjectType,
}Expand description
Default privilege grant within a profile.
Fields
role: Option<String>privileges: Vec<Privilege>on_type: ObjectTypeTrait Implementations
Sourceimpl Clone for DefaultPrivilegeGrantSpec
impl Clone for DefaultPrivilegeGrantSpec
Sourcefn clone(&self) -> DefaultPrivilegeGrantSpec
fn clone(&self) -> DefaultPrivilegeGrantSpec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DefaultPrivilegeGrantSpec
impl Debug for DefaultPrivilegeGrantSpec
Sourceimpl<'de> Deserialize<'de> for DefaultPrivilegeGrantSpec
impl<'de> Deserialize<'de> for DefaultPrivilegeGrantSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DefaultPrivilegeGrantSpec
impl JsonSchema for DefaultPrivilegeGrantSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DefaultPrivilegeGrantSpec
impl RefUnwindSafe for DefaultPrivilegeGrantSpec
impl Send for DefaultPrivilegeGrantSpec
impl Sync for DefaultPrivilegeGrantSpec
impl Unpin for DefaultPrivilegeGrantSpec
impl UnsafeUnpin for DefaultPrivilegeGrantSpec
impl UnwindSafe for DefaultPrivilegeGrantSpec