EphemeralAccessActor

Struct EphemeralAccessActor 

pub struct EphemeralAccessActor {
    pub username: String,
    pub uid: Option<String>,
    pub groups: Vec<String>,
}
Authenticated Kubernetes identity associated with an access action.

The supplied Kyverno reference policy replaces these values from the admission request’s userInfo. Without admission enforcement they are assertions by the trusted request or approval broker.

Fields

username: Stringuid: Option<String>groups: Vec<String>