pub struct EphemeralAccessRequestStatus {
pub phase: EphemeralAccessRequestPhase,
pub conditions: Vec<EphemeralAccessCondition>,
pub resolved_access: Option<ResolvedEphemeralAccess>,
pub decided_by: Option<EphemeralAccessActor>,
pub approval_expires_at: Option<String>,
pub activated_at: Option<String>,
pub expires_at: Option<String>,
pub ended_at: Option<String>,
pub last_error: Option<String>,
pub retained_memberships: Vec<ResolvedEphemeralMembership>,
}Fields
phase: EphemeralAccessRequestPhaseconditions: Vec<EphemeralAccessCondition>resolved_access: Option<ResolvedEphemeralAccess>decided_by: Option<EphemeralAccessActor>Kubernetes identity which approved or denied the request. The supplied
Kyverno reference policy overwrites this from authenticated admission
userInfo in the same status update as the terminal decision.
approval_expires_at: Option<String>activated_at: Option<String>expires_at: Option<String>ended_at: Option<String>last_error: Option<String>retained_memberships: Vec<ResolvedEphemeralMembership>Trait Implementations
Sourceimpl Clone for EphemeralAccessRequestStatus
impl Clone for EphemeralAccessRequestStatus
Sourcefn clone(&self) -> EphemeralAccessRequestStatus
fn clone(&self) -> EphemeralAccessRequestStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EphemeralAccessRequestStatus
impl Debug for EphemeralAccessRequestStatus
Sourceimpl Default for EphemeralAccessRequestStatus
impl Default for EphemeralAccessRequestStatus
Sourcefn default() -> EphemeralAccessRequestStatus
fn default() -> EphemeralAccessRequestStatus
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EphemeralAccessRequestStatus
impl<'de> Deserialize<'de> for EphemeralAccessRequestStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EphemeralAccessRequestStatus
impl JsonSchema for EphemeralAccessRequestStatus
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourcefn json_schema(generate: &mut SchemaGenerator) -> Schema
fn json_schema(generate: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more