pub struct PlanOrigin {
pub kind: String,
pub name: String,
pub uid: String,
}Expand description
Immutable identity of the resource that caused a scoped plan.
Fields
kind: Stringname: Stringuid: StringTrait Implementations
Sourceimpl Clone for PlanOrigin
impl Clone for PlanOrigin
Sourcefn clone(&self) -> PlanOrigin
fn clone(&self) -> PlanOrigin
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlanOrigin
impl Debug for PlanOrigin
Sourceimpl<'de> Deserialize<'de> for PlanOrigin
impl<'de> Deserialize<'de> for PlanOrigin
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PlanOrigin
Sourceimpl JsonSchema for PlanOrigin
impl JsonSchema for PlanOrigin
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PlanOrigin
impl PartialEq for PlanOrigin
Sourceimpl Serialize for PlanOrigin
impl Serialize for PlanOrigin
impl StructuralPartialEq for PlanOrigin