pub struct PlanScope {
pub kind: String,
pub operation: ScopedPlanOperation,
pub bundle_hash: String,
}Expand description
Scope enforced when executing a non-durable plan.
Fields
kind: Stringoperation: ScopedPlanOperationbundle_hash: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for PlanScope
impl<'de> Deserialize<'de> for PlanScope
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PlanScope
Sourceimpl JsonSchema for PlanScope
impl JsonSchema for PlanScope
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for PlanScope