pub struct PolicyPlanRef {
pub name: String,
}Expand description
Reference to the parent PostgresPolicy that generated a plan.
Fields
name: StringTrait Implementations
Sourceimpl Clone for PolicyPlanRef
impl Clone for PolicyPlanRef
Sourcefn clone(&self) -> PolicyPlanRef
fn clone(&self) -> PolicyPlanRef
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PolicyPlanRef
impl Debug for PolicyPlanRef
Sourceimpl<'de> Deserialize<'de> for PolicyPlanRef
impl<'de> Deserialize<'de> for PolicyPlanRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PolicyPlanRef
impl JsonSchema for PolicyPlanRef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PolicyPlanRef
impl RefUnwindSafe for PolicyPlanRef
impl Send for PolicyPlanRef
impl Sync for PolicyPlanRef
impl Unpin for PolicyPlanRef
impl UnsafeUnpin for PolicyPlanRef
impl UnwindSafe for PolicyPlanRef