pub struct ProfileGrantSpec {
pub privileges: Vec<Privilege>,
pub object: ProfileObjectTargetSpec,
}Expand description
Grant template within a profile.
Fields
privileges: Vec<Privilege>object: ProfileObjectTargetSpecTrait Implementations
Sourceimpl Clone for ProfileGrantSpec
impl Clone for ProfileGrantSpec
Sourcefn clone(&self) -> ProfileGrantSpec
fn clone(&self) -> ProfileGrantSpec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfileGrantSpec
impl Debug for ProfileGrantSpec
Sourceimpl<'de> Deserialize<'de> for ProfileGrantSpec
impl<'de> Deserialize<'de> for ProfileGrantSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProfileGrantSpec
impl JsonSchema for ProfileGrantSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProfileGrantSpec
impl RefUnwindSafe for ProfileGrantSpec
impl Send for ProfileGrantSpec
impl Sync for ProfileGrantSpec
impl Unpin for ProfileGrantSpec
impl UnsafeUnpin for ProfileGrantSpec
impl UnwindSafe for ProfileGrantSpec