pub struct ProfileObjectTargetSpec {
pub object_type: ObjectType,
pub name: Option<String>,
}Expand description
Object target within a profile.
Fields
object_type: ObjectTypename: Option<String>Trait Implementations
Sourceimpl Clone for ProfileObjectTargetSpec
impl Clone for ProfileObjectTargetSpec
Sourcefn clone(&self) -> ProfileObjectTargetSpec
fn clone(&self) -> ProfileObjectTargetSpec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfileObjectTargetSpec
impl Debug for ProfileObjectTargetSpec
Sourceimpl<'de> Deserialize<'de> for ProfileObjectTargetSpec
impl<'de> Deserialize<'de> for ProfileObjectTargetSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProfileObjectTargetSpec
impl JsonSchema for ProfileObjectTargetSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProfileObjectTargetSpec
impl RefUnwindSafe for ProfileObjectTargetSpec
impl Send for ProfileObjectTargetSpec
impl Sync for ProfileObjectTargetSpec
impl Unpin for ProfileObjectTargetSpec
impl UnsafeUnpin for ProfileObjectTargetSpec
impl UnwindSafe for ProfileObjectTargetSpec