pub struct ProfileSpec {
pub login: Option<bool>,
pub grants: Vec<ProfileGrantSpec>,
pub default_privileges: Vec<DefaultPrivilegeGrantSpec>,
}Expand description
A reusable privilege profile (CRD-compatible version).
This mirrors pgroles_core::manifest::Profile but derives JsonSchema.
Fields
login: Option<bool>grants: Vec<ProfileGrantSpec>default_privileges: Vec<DefaultPrivilegeGrantSpec>Trait Implementations
Sourceimpl Clone for ProfileSpec
impl Clone for ProfileSpec
Sourcefn clone(&self) -> ProfileSpec
fn clone(&self) -> ProfileSpec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProfileSpec
impl Debug for ProfileSpec
Sourceimpl<'de> Deserialize<'de> for ProfileSpec
impl<'de> Deserialize<'de> for ProfileSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProfileSpec
impl JsonSchema for ProfileSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProfileSpec
impl RefUnwindSafe for ProfileSpec
impl Send for ProfileSpec
impl Sync for ProfileSpec
impl Unpin for ProfileSpec
impl UnsafeUnpin for ProfileSpec
impl UnwindSafe for ProfileSpec