pub struct EphemeralAccessActor {
pub username: String,
pub uid: Option<String>,
pub groups: Vec<String>,
}Expand description
Authenticated Kubernetes identity associated with an access action.
The supplied Kyverno reference policy replaces these values from the
admission request’s userInfo. Without admission enforcement they are
assertions by the trusted request or approval broker.
Fields
username: Stringuid: Option<String>groups: Vec<String>Trait Implementations
Sourceimpl Clone for EphemeralAccessActor
impl Clone for EphemeralAccessActor
Sourcefn clone(&self) -> EphemeralAccessActor
fn clone(&self) -> EphemeralAccessActor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EphemeralAccessActor
impl Debug for EphemeralAccessActor
Sourceimpl<'de> Deserialize<'de> for EphemeralAccessActor
impl<'de> Deserialize<'de> for EphemeralAccessActor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EphemeralAccessActor
Sourceimpl JsonSchema for EphemeralAccessActor
impl JsonSchema for EphemeralAccessActor
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourcefn json_schema(generate: &mut SchemaGenerator) -> Schema
fn json_schema(generate: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourceimpl PartialEq for EphemeralAccessActor
impl PartialEq for EphemeralAccessActor
Sourceimpl Serialize for EphemeralAccessActor
impl Serialize for EphemeralAccessActor
impl StructuralPartialEq for EphemeralAccessActor